<?php

namespace Hrm\Customer\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hrm\Customer\Models\Customer;

class CustomerPolicy
{

    /**
     * Determine if the given user can view the customer.
     *
     * @param UserPolicy $user
     * @param Customer $customer
     *
     * @return bool
     */
    public function view(UserPolicy $user, Customer $customer)
    {
        if ($user->canDo('customer.customer.view') && $user->isAdmin()) {
            return true;
        }

        return $customer->user_id == user_id() && $customer->user_type == user_type();
    }

    /**
     * Determine if the given user can create a customer.
     *
     * @param UserPolicy $user
     * @param Customer $customer
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('customer.customer.create');
    }

    /**
     * Determine if the given user can update the given customer.
     *
     * @param UserPolicy $user
     * @param Customer $customer
     *
     * @return bool
     */
    public function update(UserPolicy $user, Customer $customer)
    {
        if ($user->canDo('customer.customer.edit') && $user->isAdmin()) {
            return true;
        }

        return $customer->user_id == user_id() && $customer->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given customer.
     *
     * @param UserPolicy $user
     * @param Customer $customer
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Customer $customer)
    {
        return $customer->user_id == user_id() && $customer->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given customer.
     *
     * @param UserPolicy $user
     * @param Customer $customer
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Customer $customer)
    {
        if ($user->canDo('customer.customer.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given customer.
     *
     * @param UserPolicy $user
     * @param Customer $customer
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Customer $customer)
    {
        if ($user->canDo('customer.customer.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
