<?php

namespace Hrm\Customer\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Hrm\Customer\Models\Customer;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Hrm\Customer\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/customer/customer/*')) {
            Route::bind('customer', function ($customer) {
                $customerrepo = $this->app->make('Hrm\Customer\Interfaces\CustomerRepositoryInterface');
                return $customerrepo->findorNew($customer);
            });
        }

        if (Request::is('*/customer/call/*')) {
            Route::bind('call', function ($call) {
                $callrepo = $this->app->make('Hrm\Customer\Interfaces\CallRepositoryInterface');
                return $callrepo->findorNew($call);
            });
        }

        if (Request::is('*/customer/status/*')) {
            Route::bind('status', function ($status) {
                $statusrepo = $this->app->make('Hrm\Customer\Interfaces\StatusRepositoryInterface');
                return $statusrepo->findorNew($status);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
